summaryrefslogtreecommitdiff
path: root/include/user/shellutil.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/user/shellutil.h')
-rw-r--r--include/user/shellutil.h46
1 files changed, 23 insertions, 23 deletions
diff --git a/include/user/shellutil.h b/include/user/shellutil.h
index 863cbd7..61d602b 100644
--- a/include/user/shellutil.h
+++ b/include/user/shellutil.h
@@ -5,27 +5,27 @@
extern "C" {
#endif
-enum {
- SCE_SHELL_UTIL_LOCK_TYPE_PS_BTN = 0x1,
- SCE_SHELL_UTIL_LOCK_TYPE_QUICK_MENU = 0x2,
- SCE_SHELL_UTIL_LOCK_TYPE_POWEROFF_MENU = 0x4,
- SCE_SHELL_UTIL_LOCK_TYPE_UNK8 = 0x8,
- SCE_SHELL_UTIL_LOCK_TYPE_USB_CONNECTION = 0x10,
- SCE_SHELL_UTIL_LOCK_TYPE_MC_INSERTED = 0x20,
- SCE_SHELL_UTIL_LOCK_TYPE_MC_REMOVED = 0x40,
- SCE_SHELL_UTIL_LOCK_TYPE_UNK80 = 0x80,
- SCE_SHELL_UTIL_LOCK_TYPE_UNK100 = 0x100,
- SCE_SHELL_UTIL_LOCK_TYPE_UNK200 = 0x200,
- SCE_SHELL_UTIL_LOCK_TYPE_MUSIC_PLAYER = 0x400,
- SCE_SHELL_UTIL_LOCK_TYPE_PS_BTN_2 = 0x800, //! without the stop symbol
-};
+typedef enum SceShellUtilLockType {
+ SCE_SHELL_UTIL_LOCK_TYPE_PS_BTN = 0x1,
+ SCE_SHELL_UTIL_LOCK_TYPE_QUICK_MENU = 0x2,
+ SCE_SHELL_UTIL_LOCK_TYPE_POWEROFF_MENU = 0x4,
+ SCE_SHELL_UTIL_LOCK_TYPE_UNK8 = 0x8,
+ SCE_SHELL_UTIL_LOCK_TYPE_USB_CONNECTION = 0x10,
+ SCE_SHELL_UTIL_LOCK_TYPE_MC_INSERTED = 0x20,
+ SCE_SHELL_UTIL_LOCK_TYPE_MC_REMOVED = 0x40,
+ SCE_SHELL_UTIL_LOCK_TYPE_UNK80 = 0x80,
+ SCE_SHELL_UTIL_LOCK_TYPE_UNK100 = 0x100,
+ SCE_SHELL_UTIL_LOCK_TYPE_UNK200 = 0x200,
+ SCE_SHELL_UTIL_LOCK_TYPE_MUSIC_PLAYER = 0x400,
+ SCE_SHELL_UTIL_LOCK_TYPE_PS_BTN_2 = 0x800 //! without the stop symbol
+} SceShellUtilLockType;
-enum {
- SCE_SHELL_UTIL_LOCK_MODE_LOCK = 0x1,
- SCE_SHELL_UTIL_LOCK_MODE_UNLOCK = 0x2,
-};
+typedef enum SceShellUtilLockMode {
+ SCE_SHELL_UTIL_LOCK_MODE_LOCK = 1,
+ SCE_SHELL_UTIL_LOCK_MODE_UNLOCK = 2
+} SceShellUtilLockMode;
-typedef void (SceShellUtilEventHandler)(int result, int mode, int type, void *userData);
+typedef void (SceShellUtilEventHandler)(int result, SceShellUtilLockMode mode, SceShellUtilLockType type, void *userData);
/**
* Init events
@@ -50,20 +50,20 @@ int sceShellUtilRegisterEventHandler(SceShellUtilEventHandler *handler, void *us
/**
* Lock event
*
* @param[in] type - One of ::ShellUtilLockType
*
* @return 0 on success, < 0 on error.
*/
-int sceShellUtilLock(int type);
+int sceShellUtilLock(SceShellUtilLockType type);
/**
* Unlock event
*
* @param[in] type - One of ::ShellUtilLockType
*
* @return 0 on success, < 0 on error.
*/
-int sceShellUtilUnlock(int type);
+int sceShellUtilUnlock(SceShellUtilLockType type);
#ifdef __cplusplus
}
@@ -50,20 +50,20 @@ int sceShellUtilRegisterEventHandler(SceShellUtilEventHandler *handler, void *us
* Lock event
*
- * @param[in] type - One of ::ShellUtilLockType
+ * @param[in] type - One of ::SceShellUtilLockType
*
* @return 0 on success, < 0 on error.
@@ -50,20 +50,20 @@ int sceShellUtilRegisterEventHandler(SceShellUtilEventHandler *handler, void *us
* Unlock event
*
- * @param[in] type - One of ::ShellUtilLockType
+ * @param[in] type - One of ::SceShellUtilLockType
*
* @return 0 on success, < 0 on error.